@@ -12,7 +12,7 @@ use strict;
 use warnings;
 
 package App::RouterColorizer;
-$App::RouterColorizer::VERSION = '1.222770';
+$App::RouterColorizer::VERSION = '1.222771';
 use Moose;
 
 use feature 'signatures';
@@ -311,20 +311,24 @@ s/^ ( \QPhysical interface: \E \S+                                     ) $/$self
     $line =~ s/^ ( \Q  Active defects : None\E ) $/$self->_colorize($1, $GREEN)/exx;
     $line =~ s/^ ( \Q  Active defects : \E \N+ ) $/$self->_colorize($1, $RED)/exx;
 
-    my $AE   = qr/ (?: ae [0-9\.]+          ) /xx;
-    my $BME  = qr/ (?: bme [0-9\.]+         ) /xx;
-    my $CBP  = qr/ (?: cbp [0-9\.]+         ) /xx;
-    my $ETH  = qr/ (?: [gx] e- [0-9\/\.]+   ) /xx;
-    my $IRB  = qr/ (?: irb [0-9\/\.]*       ) /xx;
-    my $JSRV = qr/ (?: jsrv [0-9\.]*        ) /xx;
-    my $LO   = qr/ (?: lo [0-9\.]+          ) /xx;
-    my $ME   = qr/ (?: me [0-9\.]+          ) /xx;
-    my $PFE  = qr/ (?: pf [eh] - [0-9\/\.]+ ) /xx;
-    my $PIP  = qr/ (?: pip [0-9\/\.]+       ) /xx;
-    my $VCP  = qr/ (?: vcp- [0-9\/\.]+      ) /xx;
-    my $VLAN = qr/ (?: vlan\. [0-9]+        ) /xx;
-    my $OTHER =
-      qr/ dsc | esi | gre | ipip | jsrv | lsi | mtun | pimd | pime | tap | vlan | vme | vtep /xx;
+    my $AE    = qr/ (?: ae [0-9\.]+          ) /xx;
+    my $BME   = qr/ (?: bme [0-9\.]+         ) /xx;
+    my $CBP   = qr/ (?: cbp [0-9\.]+         ) /xx;
+    my $ETH   = qr/ (?: [gx] e- [0-9\/\.]+   ) /xx;
+    my $IRB   = qr/ (?: irb [0-9\/\.]*       ) /xx;
+    my $JSRV  = qr/ (?: jsrv [0-9\.]*        ) /xx;
+    my $LO    = qr/ (?: lo [0-9\.]+          ) /xx;
+    my $ME    = qr/ (?: me [0-9\.]+          ) /xx;
+    my $PFE   = qr/ (?: pf [eh] - [0-9\/\.]+ ) /xx;
+    my $PIP   = qr/ (?: pip [0-9\/\.]+       ) /xx;
+    my $VCP   = qr/ (?: vcp- [0-9\/\.]+      ) /xx;
+    my $VLAN  = qr/ (?: vlan\. [0-9]+        ) /xx;
+    my $OTHER = qr/
+            (:? fti|fxp|gr|ip|lsq|lt|mt|sp|pp|ppd|ppe|st ) (:?-)? [0-9\/\.]+
+          | gr-\S+
+          | dsc | esi | gre | ipip | jsrv | lsi
+          | mtun | pimd | pime | rbeb | tap | vlan | vme | vtep
+    /xx;
 
     my $IFACES = qr/$AE|$BME|$CBP|$ETH|$IRB|$LO|$ME|$JSRV|$PFE|$PIP|$VCP|$VLAN|$OTHER/xx;
 
@@ -599,7 +603,7 @@ App::RouterColorizer - Colorize router CLI output
 
 =head1 VERSION
 
-version 1.222770
+version 1.222771
 
 =head1 DESCRIPTION
 
